.. Glia Packet Manager documentation main file

Welcome to Glia Packet Manager's documentation!
===============================================

.. image:: https://github.com/dbbs-lab/glia/actions/workflows/main.yml/badge.svg
   :target: https://github.com/dbbs-lab/glia
   :alt: Source Code

.. image:: https://codecov.io/gh/dbbs-lab/glia/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/dbbs-lab/glia
   :alt: Coverage

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Black Formatting

.. image:: https://readthedocs.org/projects/nrn-glia/badge/?version=latest
   :target: https://nmodl-glia.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   self
   usage
   package
   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
